@@ -2,6 +2,8 @@ use crate::prelude::*;
 
 use std::fmt::Display;
 
+use super::{article_view, comment_view, search_view, story_view};
+
 /// HelpView is a View displaying a help dialog with a list of key shortcuts and descriptions
 /// grouped by certain categories.
 pub struct HelpView {
@@ -23,7 +25,7 @@ impl HelpView {
             key,
             ColorStyle::new(
                 PaletteColor::TitlePrimary,
-                get_config_theme().code_block_bg.color,
+                config::get_config_theme().code_block_bg.color,
             ),
         );
         let desc_string = StyledString::plain(desc);
@@ -33,12 +35,12 @@ impl HelpView {
     }
 
     fn construct_help_dialog_event_view(view: Dialog) -> OnEventView<Dialog> {
-        OnEventView::new(view).on_event(get_global_keymap().close_dialog.clone(), |s| {
+        OnEventView::new(view).on_event(config::get_global_keymap().close_dialog.clone(), |s| {
             s.pop_layer();
         })
     }
 
-    fn construct_keys_view(keys: &Vec<(String, String)>) -> impl View {
+    fn construct_keys_view(keys: &[(String, String)]) -> impl View {
         let max_key_len = match keys.iter().max_by_key(|key| key.0.len()) {
             None => 0,
             Some(key) => key.0.len(),
@@ -53,13 +55,13 @@ impl HelpView {
                 .with(|s| {
                     keys.iter().for_each(|(key, desc)| {
                         s.add_child(HelpView::construct_key_view(
-                            key.clone(),
-                            desc.clone(),
+                            key.to_owned(),
+                            desc.to_owned(),
                             max_key_len + 1,
                         ));
                     });
                 })
-                .fixed_width(64),
+                .max_width(128),
         )
     }
 
@@ -78,7 +80,7 @@ impl HelpView {
             .max_height(32)
     }
 
-    pub fn to_keys<X: Display, Y: Display>(keys: Vec<(X, Y)>) -> Vec<(String, String)> {
+    pub fn process_keys<X: Display, Y: Display>(keys: Vec<(X, Y)>) -> Vec<(String, String)> {
         keys.into_iter()
             .map(|(key, desc)| (key.to_string(), desc.to_string()))
             .collect()
@@ -91,7 +93,7 @@ impl HelpView {
     ) -> Self {
         let mut key_groups: Vec<(&'static str, Vec<(String, String)>)> = key_groups
             .into_iter()
-            .map(|(group_desc, keys)| (group_desc, Self::to_keys(keys)))
+            .map(|(group_desc, keys)| (group_desc, Self::process_keys(keys)))
             .collect();
         self.key_groups.append(&mut key_groups);
         let view = self.construct_key_groups_view();
@@ -100,6 +102,12 @@ impl HelpView {
     }
 }
 
+impl Default for HelpView {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 impl ViewWrapper for HelpView {
     wrap_impl!(self.view: OnEventView<Dialog>);
 }
@@ -113,9 +121,9 @@ macro_rules! other_key_shortcuts {
                 $(
                     ($k, $d),
                 )*
-                (get_global_keymap().open_help_dialog.to_string(), "Open the help dialog"),
-                (get_global_keymap().quit.to_string(), "Quit the application"),
-                (get_global_keymap().close_dialog.to_string(), "Close a dialog"),
+                (config::get_global_keymap().open_help_dialog.to_string(), "Open the help dialog"),
+                (config::get_global_keymap().quit.to_string(), "Quit the application"),
+                (config::get_global_keymap().close_dialog.to_string(), "Close a dialog"),
             ],
         )
     };
@@ -130,13 +138,13 @@ macro_rules! view_navigation_key_shortcuts {
                 $(
                     ($k, $d),
                 )*
-                    (get_global_keymap().goto_previous_view.to_string(), "Go to the previous view"),
-                    (get_global_keymap().goto_front_page_view.to_string(), "Go to front page view"),
-                    (get_global_keymap().goto_search_view.to_string(), "Go to search view"),
-                    (get_global_keymap().goto_all_stories_view.to_string(), "Go to all stories view"),
-                    (get_global_keymap().goto_ask_hn_view.to_string(), "Go to ask HN view"),
-                    (get_global_keymap().goto_show_hn_view.to_string(), "Go to show HN view"),
-                    (get_global_keymap().goto_jobs_view.to_string(), "Go to jobs view"),
+                    (config::get_global_keymap().goto_previous_view.to_string(), "Go to the previous view"),
+                    (config::get_global_keymap().goto_front_page_view.to_string(), "Go to front page view"),
+                    (config::get_global_keymap().goto_search_view.to_string(), "Go to search view"),
+                    (config::get_global_keymap().goto_all_stories_view.to_string(), "Go to all stories view"),
+                    (config::get_global_keymap().goto_ask_hn_view.to_string(), "Go to ask HN view"),
+                    (config::get_global_keymap().goto_show_hn_view.to_string(), "Go to show HN view"),
+                    (config::get_global_keymap().goto_jobs_view.to_string(), "Go to jobs view"),
             ],
 
         )
@@ -157,10 +165,10 @@ pub struct DefaultHelpView {}
 
 impl HasHelpView for DefaultHelpView {}
 
-impl HasHelpView for StoryView {
+impl HasHelpView for story_view::StoryView {
     fn construct_help_view() -> HelpView {
-        let story_view_keymap = get_story_view_keymap();
-        let custom_keymaps: Vec<(String, String)> = get_custom_keymap()
+        let story_view_keymap = config::get_story_view_keymap();
+        let custom_keymaps: Vec<(String, String)> = config::get_custom_keymap()
             .custom_view_navigation
             .iter()
             .map(|keymap| {
@@ -214,7 +222,7 @@ impl HasHelpView for StoryView {
                     ),
                     (
                         story_view_keymap.toggle_sort_by.to_string(),
-                        "Toggle sort by date/popularity",
+                        "Toggle sort by date/popularity (only for non `Front Page` views)",
                     ),
                 ],
             ),
@@ -236,7 +244,7 @@ impl HasHelpView for StoryView {
                 ],
             ),
         ]);
-        if custom_keymaps.len() > 0 {
+        if !custom_keymaps.is_empty() {
             help_view = help_view.key_groups(vec![("Custom keymaps", custom_keymaps)]);
         }
         help_view.key_groups(vec![
@@ -249,10 +257,10 @@ impl HasHelpView for StoryView {
     }
 }
 
-impl HasHelpView for CommentView {
+impl HasHelpView for comment_view::CommentView {
     fn construct_help_view() -> HelpView {
-        let comment_view_keymap = get_comment_view_keymap();
-        let story_view_keymap = get_story_view_keymap();
+        let comment_view_keymap = config::get_comment_view_keymap();
+        let story_view_keymap = config::get_story_view_keymap();
 
         HelpView::new().key_groups(vec![
             (
@@ -282,6 +290,10 @@ impl HasHelpView for CommentView {
                         comment_view_keymap.prev_leq_level_comment.to_string(),
                         "Focus the previous comment at smaller or equal level",
                     ),
+                    (
+                        comment_view_keymap.parent_comment.to_string(),
+                        "Focus the parent comment (if exists)",
+                    ),
                 ],
             ),
             (
@@ -333,17 +345,17 @@ impl HasHelpView for CommentView {
             ),
             view_navigation_key_shortcuts!(),
             other_key_shortcuts!((
-                comment_view_keymap.reload_comment_view.to_string(),
-                "Reload the comment view"
+                comment_view_keymap.toggle_collapse_comment.to_string(),
+                "Toggle collapsing the focused comment"
             )),
         ])
     }
 }
 
-impl HasHelpView for SearchView {
+impl HasHelpView for search_view::SearchView {
     fn construct_help_view() -> HelpView {
-        let search_view_keymap = get_search_view_keymap();
-        let story_view_keymap = get_story_view_keymap();
+        let search_view_keymap = config::get_search_view_keymap();
+        let story_view_keymap = config::get_story_view_keymap();
 
         HelpView::new().key_groups(vec![
             (
@@ -419,9 +431,9 @@ impl HasHelpView for SearchView {
     }
 }
 
-impl HasHelpView for ArticleView {
+impl HasHelpView for article_view::ArticleView {
     fn construct_help_view() -> HelpView {
-        let article_view_keymap = get_article_view_keymap().clone();
+        let article_view_keymap = config::get_article_view_keymap().clone();
         HelpView::new().key_groups(vec![
             (
                 "Navigation",
